<?php
$lang['invalidemail'] = 'L&#039;adre&ccedil;a d&#039;email no &eacute;s v&agrave;lida';
$lang['empty_query'] = 'Consulta buida?? %s';
$lang['no_db_driver'] = 'No s&#039;han trobat drivers de base de dades compatibles';
$lang['test_check_output_buffering'] = 'Verfificant la capacitat de sortida';
$lang['test_check_output_buffering_failed'] = 'Output buffering est&agrave; deshabilitat. Altament probable que no puguis utilitzar cap fucni&oacute; que ho requereixi';
$lang['phpinfo'] = 'Mostra informaci&oacute; de PHP';
$lang['mod_security'] = 'Mod Security d&#039;Apache';
$lang['test_check_tempnam'] = 'Verificant la funci&oacute; tempnam';
$lang['test_check_db_drivers'] = 'Drivers de BD';
$lang['test_check_db_drivers_failed'] = 'No s&#039;han trobat dirvers de BD';
$lang['test_check_register_globals'] = 'Verificant l&#039;opcio PHP de registre de globals';
$lang['test_check_register_globals_failed'] = 'PHP register globals active. For security concern ask to disable this.';
$lang['test_check_disable_functions'] = 'Verificant funcions PHP deshabilitades';
$lang['test_check_disable_functions_failed'] = 'Aix&ograve; &eacute;s una llista de funcions deshabilitades en el teu servidor';
$lang['install_admin_db_port'] = 'Port de base de dades';
$lang['install_admin_db_port_info'] = 'If you don&#039;t know, leave this blank to use default settings.';
$lang['install_admin_db_socket'] = 'connector de Base de dades';
$lang['install_admin_db_socket_info'] = 'NO SUPORTAT';
$lang['install_admin_frontendlang'] = 'Idioma per defecte de la part d&#039;usuari final. Aix&ograve; ajusta el &#039;locale&#039; utilitzat per diverses funcions de gesti&oacute; de dates, etc.';
$lang['install_default_encoding'] = 'En la majoria de casos, default_encoding hauria de ser utf-8. Si en volguessis un de diferents, es pot canviar per&ograve; cal considerar que les traduccions a diferents idiomes s&oacute;n totes en utf-8';
$lang['installer_done'] = '[fet]';
$lang['installer_failed'] = '[ha fallat]';
$lang['create_permission'] = 'Crea perm&iacute;s ...';
$lang['add_column_sql'] = 'Afegint columna a la taula %s ...';
$lang['update_table_sql'] = 'Actualitzar %s taula ...';
$lang['installing_module'] = 'Instal.lant el m&ograve;dul %s ...';
$lang['updating_schema_version'] = 'Actualitzant la versi&oacute; d&#039;esquema %s ...';
$lang['upgrade_config'] = 'Actualitzant config.php';
$lang['upgrade_config_info'] = 'configuraci&oacute; de l&#039;actualitzaci&oacute;';
$lang['upgrade_failed_again'] = 'Una o m&eacute;s actualitzacions han fallat. Si et plau, corregeix elproblema i pica el bot&oacute; de sota per tornar a verificar';
$lang['upgrade_cache_dirs'] = 'Esborrant els directoris de mem&ograve;ria cau';
$lang['cannot_clean_cache_dirs'] = 'No puc esborrar els directoris de mem&ograve;ria cau!';
$lang['upgrade_schema'] = 'Actualitzant l&#039;esquema';
$lang['need_upgrade_schema'] = 'CMS necessita una actualitzaci&oacute;.<br />Est&agrave;s treballant amb l&#039;esquema de versi&oacute; %s i necessites pujar fins la versi&oacute; %s';
$lang['schema_ok'] = 'Ara la base de dades CMS est&agrave; actualitzada. S&#039;est&agrave; utilitzant la versi&oacute; d&#039;esquema %s';
$lang['noneed_upgrade_schema'] = 'Ara la base de dades CMS est&agrave; actualitzada. S&#039;est&agrave; utilitzant la versi&oacute; d&#039;esquema %s';
$lang['upgrade_modules'] = 'Actualitzaci&oacute; de m&ograve;duls';
$lang['noneed_upgrade_modules'] = 'Els m&ograve;duls del nucli b&agrave;sic estan actualitzats';
$lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of &quot;%s&quot; module from %s to %s ...';
$lang['upgrade_event_module_from_to'] = 'Upgrading Events of &quot;%s&quot; module from %s to %s ...';
$lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a &quot;Site Down for Maintainence&quot; message on your site';
$lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it&#039;s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Modules page and looking for any listed as &quot;Needs Upgrade&quot;';
$lang['upgrade_complete'] = 'Proc&eacute;s d&#039;actualitzaci&oacute; acomplert';
$lang['upgrade_end'] = 'CMS is up to date. Please click %s to go to your CMS site or you can %s.';
$lang['here'] = 'aqu&iacute;';
$lang['go_to_admin'] = 'V&eacute;s al penell d&#039;administraci&oacute;';
$lang['errorfilenot'] = 'Arxiu no localitzat!';
$lang['errorfilenotwritable'] = 'Arxiu no modificable!';
$lang['nofiles'] = 'Aquest recurs no existeix';
$lang['is_directory'] = 'Aquest recurs &eacute;s un directori!';
$lang['is_readable_false'] = 'Aquest recurs no &eacute;s llegible!';
$lang['checksum_match'] = 'La signatura encaixa!';
$lang['checksum_not_match'] = 'La signatura no encaixa!';
$lang['not_checksum'] = 'No hi ha signatura per recuperar!';
$lang['format_datetime'] = '%c';
$lang['upload_err_ini_size'] = 'L&#039;arxiu pujat excedeix la directiva upload_max_filesize de l&#039;arxiu php.ini';
$lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
$lang['upload_err_partial'] = 'The uploaded file was only partially uploaded.';
$lang['upload_err_no_file'] = 'No file was uploaded.';
$lang['upload_err_no_tmp_dir'] = 'Missing a temporary folder.';
$lang['upload_err_cant_write'] = 'Failed to write file to disk.';
$lang['upload_err_extension'] = 'File upload stopped by extension.';
$lang['upload_err_empty'] = 'File has size zero';
$lang['upload_err_unknown'] = 'File upload error unknown.';
$lang['function_file_uploads_off'] = 'file_uploads is off in your php!';
$lang['upload_file_no_readable'] = 'File upload no readable!';
$lang['upload_file_multiple'] = 'Multiple file uploads not allowed!';
$lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
$lang['test_check_magic_quotes_gpc_failed'] = 'When magic_quotes are on, all single-quote, double quote and backslash are escaped with a backslash automatically. You can to have problems in save templates.';
$lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
$lang['test_check_magic_quotes_runtime_failed'] = 'When magic_quotes are on, most functions that return data from any sort of external source including databases and text files will have quotes escaped with a backslash. You can to have problems.';
$lang['install_admin_checksum'] = 'Check your installation';
$lang['upgrade_admin_checksum'] = 'Check your system upgrading';
$lang['checksum'] = 'Checksum test';
$lang['checksum_file'] = 'Checksum file';
$lang['install_test_checksum'] = 'You can validate the integrity of your CMS files by comparing against original CMS checksum. It can assist in finding problems with uploads.';
$lang['checksum_passed'] = 'All checksums match!';
$lang['checksum_failed'] = 'Checksum match with errors. Look at the help for more information';
$lang['test_check_open_basedir'] = 'Check for PHP Open Basedir';
$lang['test_check_open_basedir_failed'] = 'Open basedir restrictions are in effect. You may have difficulty with some addon functionality with this restriction.';
$lang['unlimited'] = 'Unlimited';
$lang['test_open_basedir_session_save_path'] = 'Open basedir restrictions appear to be in effect. If you have SESSION problems and ini_set works, you can try to enable session by cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
$lang['install_warn_db_createtables'] = 'Normally this field should be checked at all times.  Use caution when disabling this feature';
$lang['install_admin_tablesnotcreated'] = 'Process complete. The installation process has completed, at your request database tables were not created. However, the config file has been reset and all pre-installation tests have passed. Thank you, and here is your';
$lang['info_create_dir_and_file'] = 'The HTTP Process owner cannot create a file inside a directory that it owns. This probably means that safe mode is enabled in some way.  Many functions inside CMS made simple will not operate properly without this ability. Continuing is not possible.';
$lang['test_create_dir_and_file'] = 'Checking if the httpd process can create a file inside of a directory it created.';
$lang['cms_site'] = 'Lloc CMS';
$lang['or_greater'] = 'O superior';
$lang['sitename'] = 'Nom del Lloc';
$lang['warning_safe_mode'] = '<strong><em>WARNING:</em></strong> PHP Safe mode is enabled.  This will cause difficulty with files uploaded via the web browser interface, including images, theme and module XML packages.  You are advised to contact your site administrator to see about disabling safe mode.';
$lang['test'] = 'Prova';
$lang['results'] = 'Resultats';
$lang['untested'] = 'No provat';
$lang['owner'] = 'Propietari';
$lang['permissions'] = 'Permisos';
$lang['off'] = 'Off';
$lang['on'] = 'On';
$lang['permission_information'] = 'Informaci&oacute; de permisos';
$lang['server_os'] = 'Informaci&oacute; de sistema operatiu';
$lang['server_api'] = 'API de servidor';
$lang['server_software'] = 'Programari de servidor';
$lang['server_information'] = 'Informaci&oacute; de servidor';
$lang['session_save_path'] = 'Cam&iacute; per desar sessi&oacute;';
$lang['max_execution_time'] = 'M&agrave;xim temps d&#039;execuci&oacute;';
$lang['gd_version'] = 'Versi&oacute; de GD';
$lang['upload_max_filesize'] = 'Mida m&agrave;xima de pujada';
$lang['post_max_size'] = 'Mida m&agrave;xima de Post';
$lang['memory_limit'] = 'L&iacute;mit de mem&ograve;ria de PHP';
$lang['server_db_type'] = 'Base de dades del servidor';
$lang['server_db_version'] = 'Versi&oacute; de la base de dades del servidor';
$lang['phpversion'] = 'Versi&oacute; actual del PHP';
$lang['safe_mode'] = 'Mode segur de PHP';
$lang['php_information'] = 'Informaci&oacute; de PHP';
$lang['cms_install_information'] = 'Informaci&oacute; d&#039;instal.laci&oacute; de CMS';
$lang['cms_version'] = 'Versi&oacute; de CMS';
$lang['systeminfo_copy_paste'] = 'Please copy and paste this selected text into your forum posting';
$lang['help_systeminformation'] = 'The information displayed below is collected from a variety of locations, and summarized here so that you may be able to conveniently find some of the information required when trying to diagnose a problem or request help with your CMS Made Simple installation.';
$lang['systeminfo'] = 'Informaci&oacute; del sistema';
$lang['systeminfodescription'] = 'Display various pieces of information about your system that may be useful in diagnosing problems';
$lang['error'] = 'Error';
$lang['new_version_available'] = '<em>Notice:</em> A new version of CMS Made Simple is available.  Please notify your administrator.';
$lang['info_urlcheckversion'] = 'If this url is the word &quot;none&quot; no checks will be made.<br/>An empty string will result in a default URL being used.';
$lang['urlcheckversion'] = 'Check for new CMS versions using this URL';
$lang['read'] = 'Llegeix';
$lang['write'] = 'Escriu';
$lang['execute'] = 'Executa';
$lang['group'] = 'Grup';
$lang['other'] = 'Altres';
$lang['global_umask'] = 'File Creation Mask (umask)';
$lang['errorcantcreatefile'] = 'Could not create a file (permissions problem?)';
$lang['add'] = 'Afegeix';
$lang['about'] = 'Sobre';
$lang['action'] = 'Acci&oacute;';
$lang['actionstatus'] = 'Acti&oacute;/Estat';
$lang['active'] = 'Actiu';
$lang['cantremove'] = 'No es pot esborrar';
$lang['changepermissions'] = 'Modifica permisos';
$lang['changepermissionsconfirm'] = 'USE CAUTION\n\nThis action will attempt to ensure that all of the files making up the module are writable by the web server.\nAre you sure you want to continue?';
$lang['success'] = '&Egrave;xit';
$lang['advanced'] = 'Avan&ccedil;at';
$lang['back'] = 'Enrere cap al men&uacute;';
$lang['cancel'] = 'Cancel.la';
$lang['cantchmodfiles'] = 'No s&#039;han pogut canviar els permisos d&#039;alguns arxius';
$lang['cantremovefiles'] = 'Problem Removing Files (permissions?)';
$lang['create'] = 'Crear';
$lang['database'] = 'Base de dades';
$lang['databaseprefix'] = 'Prefixe de base de dades';
$lang['databasetype'] = 'Tipus de base de dades';
$lang['date'] = 'Data';
$lang['default'] = 'Per defecte';
$lang['delete'] = 'Esborra';
$lang['deleteconfirm'] = 'N&#039;est&agrave;s segur que vols esborrar - %s -?';
$lang['description'] = 'Descripci&oacute;';
$lang['directoryexists'] = 'Aquest directori ja existeix.';
$lang['down'] = 'Avall';
$lang['edit'] = 'Edita';
$lang['email'] = 'Adre&ccedil;a correu-e';
$lang['errordeletingfile'] = 'No s&#039;ha pogut esborrar l&#039; arxiu. Problema de permisos?';
$lang['errordirectorynotwritable'] = 'No permission to write in directory.  This could be caused by file permissions and ownership.  Safe mode may also be in effect.';
$lang['cachenotwritable'] = 'Cache folder is not writable. Clearing cache will not work. Please make the tmp/cache folder have full read/write/execute permissions (chmod 777).  You may also have to disable safe mode.';
$lang['modulesnotwritable'] = 'The modules folder is not writable, if you would like to install modules by uploading an XML file you need to make the modules folder have full read/write/execute permissions (chmod 777).  Safe mode may also be in effect.';
$lang['false'] = 'Fals';
$lang['settrue'] = 'Set True';
$lang['filename'] = 'Filename';
$lang['filesize'] = 'File Size';
$lang['help'] = 'Help';
$lang['language'] = 'Language';
$lang['lastname'] = 'Last Name';
$lang['name'] = 'Name';
$lang['password'] = 'Password';
$lang['passwordagain'] = 'Password (again)';
$lang['remove'] = 'Remove';
$lang['saveconfig'] = 'Save Config';
$lang['true'] = 'True';
$lang['setfalse'] = 'Set False';
$lang['type'] = 'Type';
$lang['typenotvalid'] = 'Type is not valid';
$lang['unknown'] = 'Unknown';
$lang['user'] = 'Usuari';
$lang['userdefinedtags'] = 'User Defined Tags';
$lang['usermanagement'] = 'User Management';
$lang['username'] = 'Username';
$lang['usernameincorrect'] = 'Username or password incorrect';
$lang['version'] = 'Versi&oacute;';
$lang['install_title'] = 'CMS Made Simple Install (step %s)';
$lang['install_system'] = 'Install System';
$lang['install_thanks'] = 'Thanks for installing CMS Made Simple';
$lang['upgrade_title'] = 'CMS Made Simple Upgrade (step %s)';
$lang['upgrade_system'] = 'Upgrade System';
$lang['upgrade_thanks'] = 'Thanks for upgrading CMS Made Simple to';
$lang['install_please_read'] = 'Please read the <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Installation Troubleshooting</a> page in the CMS Made Simple Documentation Wiki.';
$lang['install_checking'] = 'Checking permissions and PHP settings';
$lang['install_test'] = 'Test';
$lang['install_result'] = 'Result';
$lang['install_required_settings'] = 'Required settings';
$lang['install_recommended_settings'] = 'Recommended settings';
$lang['install_you_have'] = 'You have';
$lang['install_legend'] = 'Legend';
$lang['install_symbol'] = 'Symbol';
$lang['install_definition'] = 'Definition';
$lang['install_value_passed'] = 'A required test passed';
$lang['install_value_failed'] = 'A required test failed';
$lang['install_error_fragment'] = 'Info Installation Troubleshooting';
$lang['install_value_required'] = 'A setting is below a required minimum value';
$lang['install_value_recommended'] = 'A setting is above the required value, but below the recommended value<br />or... A capability that <em>may</em> be required for some optional functionality is unavailable';
$lang['install_value_exceed'] = 'A setting meets or exceeds the recommended threshhold<br />or... A capability that <em>may</em> be required for some optional functionality is available';
$lang['install_test_failed'] = 'One or more tests have failed. You can still install the system but some functions may not work correctly.<br />Please try to correct the situation and click &quot;Try Again&quot;, or click the Continue button.';
$lang['install_test_passed'] = 'All tests passed (at least at a minimum level). Please click the Continue button.';
$lang['install_failed_again'] = 'One or more tests have failed. Please correct the problem and click the button below to recheck.';
$lang['install_try_again'] = 'Try Again';
$lang['install_continue'] = 'Continue';
$lang['failure'] = 'Failure';
$lang['caution'] = 'Caution';
$lang['install_admin_umask'] = 'Test File Creation Mask';
$lang['install_test_umask'] = 'Please click Test button for check  ..............................';
$lang['test_umask_text'] = 'umask (abbreviated from user file creation mode mask) is a function in POSIX environments which affects the default file system mode for newly created files and directories of the current process. It controls which of the file permissions will not be set for any newly created file.';
$lang['test_check_umask'] = 'Result test on file created in';
$lang['test_umask_not_given'] = 'Umask not given';
$lang['test_check_umask_failed'] = 'Test umask failed';
$lang['test_username_not_given'] = 'Username not given!';
$lang['test_username_illegal'] = 'Username contains illegal characters!';
$lang['test_not_both_passwd'] = 'Not both password fields given!';
$lang['test_passwd_not_match'] = 'Password fields do not match!';
$lang['test_email_accountinfo'] = 'E-mail accountinfo selected, but no E-mail address given!';
$lang['test_database_prefix'] = 'Database prefix contains invalid characters';
$lang['test_no_dbms'] = 'No dbms selected!';
$lang['test_could_not_connect_db'] = 'Could not connect to the database. Verify that username and password are correct, and that the user has access to the given database.';
$lang['test_could_not_drop_table'] = 'Could not drop a table. Verify that the user has privileges to drop tables in the given database.';
$lang['test_could_not_create_table'] = 'Could not create a table. Verify that the user has privileges to create tables in the given database.';
$lang['test_check_php'] = 'Checking for PHP version 4.3+';
$lang['test_min_recommend'] = '(minimum %s, recommend %s or greater)';
$lang['test_min_recommend_plus'] = '(min %s, recommend %s+)';
$lang['test_requires_php_version'] = 'CMS Made Simple requires a php version of 4.3 or greater (you have %s), but PHP %s or greater is recommended to ensure maximum compatibility with third party addons';
$lang['test_check_md5_func'] = 'Checking for md5 Function';
$lang['test_check_safe_mode'] = 'Checking for safe mode';
$lang['test_check_safe_mode_failed'] = 'PHP safe mode could create some problems with uploading files and other functions. It all depends on how strict your server safe mode settings are.';
$lang['test_check_tokenizer'] = 'Checking for tokenizer functions';
$lang['test_check_tokenizer_failed'] = 'Not having the tokenizer could cause pages to render as purely white. We recommend you have this installed, but your website may work fine without it.';
$lang['test_check_gd'] = 'Checking for GD library';
$lang['test_check_gd_failed'] = 'GD library are mandatory for some modules and functionality.';
$lang['test_check_write'] = 'Checking write permission on';
$lang['test_may_not_exist'] = 'This file may not exist yet. If it does not, you should create an empty file with this name. Please also ensure that this file writable by the web server process.';
$lang['could_not_retrieve_a_value'] = 'Could not retrieve a value.... passing anyways.';
$lang['displaying_the_value_originally'] = '<br />Displaying the value originally set in the config file (this may not be accurate).';
$lang['test_check_xml_func'] = 'Checking for basic XML (expat) support';
$lang['test_check_xml_failed'] = 'XML support is not compiled into your php install. You can still use the system, but will not be able to use any of the remote module installation functions.';
$lang['test_allow_url_fopen_failed'] = 'When allow url fopen is disabled you will not be able to accessing URL object like file using the ftp or http protocol.';
$lang['test_remote_url'] = 'Test for remote URL';
$lang['test_remote_url_failed'] = 'You will probably not be able to open a file on a remote web server.';
$lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
$lang['remote_connection_timeout'] = 'Connection Timed Out!';
$lang['search_string_find'] = 'Connection ok!';
$lang['connection_failed'] = 'Connection failed!';
$lang['remote_response_ok'] = 'Remote response: ok!';
$lang['remote_response_404'] = 'Remote response: not found!';
$lang['remote_response_error'] = 'Remote response: error!';
$lang['test_check_file_upload'] = 'Checking file uploads';
$lang['test_check_file_failed'] = 'When file uploads are disabled you will not be able to use any of the file uploading facilities included in CMS Made Simple. If possible, this restriction should be lifted by your system admin to properly use all file management features of the system. Proceed with caution.';
$lang['test_check_memory'] = 'Checking PHP memory limit';
$lang['test_check_memory_failed'] = 'You may not have enough memory to run CMSMS correctly, or with all of your desired addons. If possible, you should try to get your system admin to raise this value. Proceed with caution.';
$lang['test_check_time_limit'] = 'Checking PHP time limit in second';
$lang['test_check_time_limit_failed'] = 'Number of seconds a script is allowed to run. If this is reached, the script returns a fatal error.';
$lang['test_check_post_max'] = 'Checking max post size';
$lang['test_check_post_max_failed'] = 'You will probably not be able to submit (larger) data. Please be aware of this restriction.';
$lang['test_check_upload_max'] = 'Checking max upload file size';
$lang['test_check_upload_max_failed'] = 'You will probably not be able to upload (larger) files using the included file management functions. Please be aware of this restriction.';
$lang['test_check_writable'] = 'Checking if %s is writable';
$lang['test_check_upload_failed'] = 'The uploads folder is not writable. You can still install the system, but you will not be able to upload files via the Admin Panel.';
$lang['test_check_images_failed'] = 'The images folder is not writable. You can still install the system, but you will not be able to upload and use images via the Admin Panel.';
$lang['test_check_modules_failed'] = 'The modules folder is not writable. You can still install the system, but you will not be able to upload modules via the Admin Panel.';
$lang['test_check_file_get_contents'] = 'Checking for file_get_contents';
$lang['test_check_file_get_contents_failed'] = 'The file_get_contents function was added in PHP 4.3 and although a workaround has been added that should allow most functionality that uses this function to work properly in PHP 4.2, it may be advisable to upgrade to PHP 4.3 or greater.';
$lang['test_check_session_save_path'] = 'Checking if session.save_path is writable';
$lang['test_empty_session_save_path'] = 'Your session.save_path is empty. PHP will use the temporary directory of your OS. If you have SESSION problems and ini_set works you can try to enable session cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
$lang['test_check_session_save_path_failed'] = 'Your session.save_path is &quot;%s&quot;. Not having this as writable may make logins to the Admin Panel not work. You may want to look into making this path writable if you have trouble logging into the Admin Panel. This test may fail if safe_mode is enabled (see below).';
$lang['test_check_ini_set'] = 'Checking if ini_set works';
$lang['test_check_ini_set_failed'] = 'Although the ability to override php ini settings is not mandatory, some addon (optional) functionality uses ini_set to extend timeouts, and allow uploading of larger files, etc. You may have difficulty with some addon functionality without this capability. This test may fail if safe_mode is enabled (see below).';
$lang['install_admin_header'] = 'Admin Account Information';
$lang['install_admin_info'] = 'Select the username, password and email address for your admin account. Please make sure you record this password somewhere, as there will be no other way to login to your CMS Made Simple admin system without it.';
$lang['install_admin_email'] = 'E-mail Address';
$lang['install_admin_email_info'] = 'E-Mail Account Information';
$lang['install_admin_email_note'] = '<strong>Note:</strong> This function uses the php&#039;s mail function. If you don&#039;t receive this email, it may be an indication that your server is not properly configured and that you should contact your host administrator.';
$lang['install_admin_sitename'] = 'This is the name of your site. It will be used in various places of the default templates and can be used anywhere with the	{sitename} tag.';
$lang['install_admin_db'] = 'Database Information';
$lang['install_admin_db_info'] = '<p>Make sure you have created your database and granted full privileges to a user to use that database.</p>
<p>For MySQL, use the following:</p>
<p>Log in to mysql from a console and run the following commands:</p>
<ol>
<li>create database cms; (use whatever name you want here but make sure to remember it, you&#039;ll need to enter it on this page)</li>
<li>grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039;;</li>
</ol>';
$lang['install_admin_follow'] = 'Please complete the following fields';
$lang['install_admin_db_type'] = 'Database Type';
$lang['install_admin_no_db'] = 'No valid database drivers appear to be compiled into your PHP install. Please confirm that you have mysql, mysqli, and/or postgres7 support installed, and try again.';
$lang['install_admin_db_host'] = 'Database host address';
$lang['install_admin_db_name'] = 'Database name';
$lang['install_admin_db_create'] = 'Create Tables (Warning: Deletes existing data)';
$lang['install_admin_db_prefix'] = 'Table prefix';
$lang['install_admin_db_sample'] = 'Install sample content and templates';
$lang['retry'] = 'Retry';
$lang['install_admin_db_create_seq'] = 'Creating %s table sequence...';
$lang['install_admin_importing'] = 'Importing sample data...';
$lang['invalid_query'] = 'Invalid query: %s';
$lang['install_creating_table'] = '<p>Creating %s table... [%s]</p>';
$lang['install_creating_index'] = '<p>Creating index in %s table... [%s]</p>';
$lang['done'] = 'done';
$lang['failed'] = 'failed';
$lang['install_admin_error_schema'] = 'Error in retrieve SQL schema';
$lang['install_admin_set_account'] = 'Setting admin account information...';
$lang['install_admin_set_sitename'] = 'Setting sitename...';
$lang['install_admin_setup'] = 'Now let&#039;s continue to setup your configuration file, we already have most of the stuff we need. Chances are you can leave all these values alone, so when you are ready, click Continue.';
$lang['install_admin_docroot'] = 'CMS Document root (as seen from the webserver)';
$lang['install_admin_docroot_path'] = 'Path to the Document root';
$lang['install_admin_querystring'] = 'Query string (leave this alone unless you have trouble, then edit config.php by hand)';
$lang['invalid_querys'] = '<b>WARNING<b/>: Invalid queries on your DB!';
$lang['install_admin_sitedown'] = 'Error: Could not remove the tmp/cache/SITEDOWN file. Please remove manually.';
$lang['install_admin_update_hierarchy'] = 'Updating hierarchy positions...';
$lang['install_admin_set_core_event'] = 'Configurant esdeveniments de nucli...';
$lang['install_admin_install_modules'] = 'Instal.lant m&ograve;duls...';
$lang['install_admin_index_search'] = 'Index Search...';
$lang['install_admin_clear_cache'] = 'Clearing site cache (if any)...';
$lang['install_admin_emailing'] = 'E-mailing admin account information...';
$lang['install_admin_congratulations'] = 'Congratulations, you are all setup - here is your <a href="%s">CMS site</a>';
$lang['could_not_connect_db'] = 'Could not connect to the database. Verify that username and password are correct, and that the user has access to the given database.';
$lang['cannot_write_config'] = 'Error: no es pot escriure a %s.';
$lang['email_accountinfo_subject'] = 'CMS Made Simple Admin Account Information';
$lang['email_accountinfo_message'] = 'Thank you for installing CMS Made Simple.

This is your new account information:
username: %s
password: %s

Log into the site admin here: %s';
$lang['utma'] = '156861353.3109145977533247500.1225311312.1259216857.1259266070.48';
$lang['utmz'] = '156861353.1254088757.35.2.utmccn=(referral)|utmcsr=66.147.244.155|utmcct=/~clubcocc/cmsmadesimple/install/index.php|utmcmd=referral';
$lang['qca'] = 'P0-894451108-1250455823820';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>